龙猫 (豆瓣)
Description: 龙猫电影简介和剧情介绍,龙猫影评、图片、预告片、影讯、论坛、在线购票
Keywords: 龙猫,となりのトトロ,龙猫影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.26豆瓣电影Top250

# 龙猫 となりのトトロ (1988)

导演: 宫崎骏
编剧: 宫崎骏
主演: 日高法子 / 坂本千夏 / 糸井重里 / 岛本须美 / 北林谷荣 / 高木均 / 雨笠利幸 / 丸山裕子 / 广濑正志 / 鹫尾真知子 / 铃木玲子 / 千叶繁 / 龙田直树 / 鳕子 / 西村朋纮 / 石田光子 / 神代知衣 / 中村大树 / 水谷优子 / 平松晶子 / 大谷育江
类型: 动画 / 奇幻 / 冒险
制片国家/地区: 日本
语言: 日语
上映日期: 2018-12-14(中国大陆) / 1988-04-16(日本)
片长: 86分钟
又名: 邻居托托罗 / 邻家的豆豆龙 / 隔壁的特特罗 / Tonari no Totoro / My Neighbor Totoro
IMDb: tt0096283
豆瓣评分
引用
9.2
1204114人评价
5星
64.4%
4星
29.5%
3星
5.8%
2星
0.2%
1星
0.1%
好于 99% 动画片
好于 99% 奇幻片
想看 看过
评价:
推荐

## 龙猫的剧情简介 · · · · · ·

小月的母亲生病住院了，父亲带着她与四岁的妹妹小梅到乡间的居住。她们对那里的环境都感到十分新奇，也发现了很多有趣的事情。她们遇到了很多小精灵，她们来到属于她们的环境中，看到了她们世界中很多的奇怪事物，更与一只大大胖胖的龙猫成为了朋友。龙猫与小精灵们利用他们的神奇力量，为小月与妹妹带来了很多神奇的景观，令她们大开眼界。
妹妹小梅常常挂念生病中的母亲，嚷着要姐姐带着她去看母亲，但小月拒绝了。小梅竟然自己前往，不料途中迷路了，小月只好寻找她的龙猫及小精灵朋友们帮助。 ©豆瓣

## 龙猫的演职员 · · · · · · ( 全部 31 )

- 宫崎骏 导演
- 日高法子 配 小月 サツキ Satsuki
- 坂本千夏 配 小梅 メイ Mei
- 糸井重里 配 爸爸 / 草壁先生 とうさん Tatsuo Kusakabe
- 岛本须美 配 妈妈 かあさん Yasuko Kusakabe
- 北林谷荣 配 婆婆 ばあちゃん Granny

## 龙猫的视频和图片 ······ ( 预告片9 | 视频评论2 · 添加 | 图片1185 · 添加 )

## 龙猫的获奖情况 · · · · · · ( 全部 )

- 第13届报知映画赏
- 最佳导演
- 宫崎骏

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  哈尔的移动城堡

  幽灵公主

  风之谷

  魔女宅急便

  大闹天宫

  千与千寻

  红猪

  猫的报恩

  哪吒闹海

我要写短评

## 龙猫的短评 · · · · · · ( 全部 226067 条 )

热门 / 最新 / 好友

### 8857 有用 寂地 看过 2006-01-03 17:44:39

那音乐壮丽的响起的时候，觉得心里被一种温暖充满，然后实在控制不住眼泪了，不是因为伤心，而是因为，它给人的感觉，实在美好到无法表达了．

### 4652 有用 Lan~die 看过 2007-02-10 09:19:52

龙猫，好烂漫的幻想。 消失的乡下风景、慈祥的爷爷奶奶、嬉笑追逐的儿时玩伴，是童年最纯真美好的回忆。

### 9361 有用 mjxian 看过 2012-09-19 22:16:47

如果你在下雨天的车站，遇到被淋湿的妖怪，请把雨伞借给它，你会得到森林的通行证哦

### 1884 有用 赫恩曼尼 看过 2013-08-08 00:28:36

宫崎骏真是个内心柔软的天才。能给这个残酷的世界这么多温暖。龙猫真像童年时的一场梦，长大之后似乎忘记了，突然看见它毛茸茸的身躯，就想起了所有的奢望。这大概就是我们得以在孤独中相互告慰的东西吧。无论怎样，成熟都是一场病，而能够治愈它的，大概只有对这个世界最温存的渴望。

### 2329 有用 Q。 看过 2008-09-01 09:45:33

人人心中都有个龙猫，童年就永远不会消失，爱是最美的拥有～ ★★★★★

> 更多短评 226067条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 龙猫的影评 · · · · · · ( 全部 2626 条 )

热门 / 最新 / 好友
Lindsey落枕 2008-04-30 21:34:16

## 像孩子一样大呼小叫

森林里藏匿着一种神奇的生物，它的名字叫多多洛。 它有着圆滚滚的庞大身躯与软软的毛，晚上会领着自己的小朋友在树枝的最顶端吹出悠扬的乐曲，下雨的时候戴着一顶荷叶小帽，要回家的时候则召来它威风凛凛的龙猫公交车。 你只能巧遇它，却无法找寻它。它会慷慨地帮... (展开)
2636 119 211回应 收起
如 2007-05-23 21:50:23

## 愿人人心中都有龙猫

刚刚看完了宫崎峻的《龙猫》，有种温馨地想要流泪的感觉。 小时侯，非常喜欢范晓萱，也非常喜欢那首《豆豆龙》（豆豆龙应该就是指龙猫），原来就是这部动画片的主题曲，所以听起来感到自己像是又回到了童年，正好与影片的主题相得益彰。于是心中起了层层波浪，回忆、感动... (展开)
1473 82 131回应 收起
小沙弥 2005-11-04 12:26:59

## 殿堂级大师的作品

这篇影评可能有剧透

《龙猫》是宫崎骏的在STUDIO GHIBLI的第三部电影，因为这部平静而温馨的电影使得龙猫这个可爱的生物在全世界都家喻户晓。《龙猫》十分适合一家老小齐齐观看的。 　　“在我们乡下，有一种神奇的小精灵，他们就像我们的邻居一样，居住在我们的身边嬉戏、玩耍。但是普通人... (展开)
673 46 95回应 收起
冷自如 2008-12-04 14:52:04

## 多多洛的隐喻

《龙猫》知识简本： 1.图中胖胖的动物在片中被称为多多洛 2.多多洛其实是鼠类 3.龙猫在片中其实是多多洛的公交车 ----------------------------------- 我们被《龙猫》所吸引，然而那羡慕与向往之心并不是因为身边缺少一个多多洛。 多多洛不是无所不能的神仙精灵，不是... (展开)
476 25 13回应 收起
小林君 2010-07-25 11:14:26

## 即使龙猫的故事来源于真实事件，也不会减弱我们对故事本身的爱

这篇影评可能有剧透

这个说法是在2007年2月左右开始传开，动画龙猫中其实有很多里设定和里故事，稍微整理了一下日文的资料，大概的翻译一下，是巧合还是真实信不信就在于在个人了。大家推测的版本很多，其中有一种是其实两姐妹已经在故事的途中死掉了，然后是父亲在想像如果两姐妹活着的话应该会这... (展开)
1533 1076 442回应 收起
苏言 2009-07-09 22:09:31

## 第一次在动画片里看见小朋友

我第一次在动画片里看见小朋友。 那个孩子是怎样的呢？ 是姐姐的跟屁虫，姐姐走到哪她就跟到哪，姐姐看哪儿她也跟着看哪儿，姐姐说什么她也跟着说什么，姐姐不在就找姐姐 穿上套装第一句就问“我像不像姐姐？” 害怕陌生人 看到桌面上自己喜欢吃的就边叫边跳，兴奋地不停... (展开)
336 2 21回应 收起
木卫二 2018-12-16 00:43:11 #《龙猫》有哪些亮点和记忆点？

## 昭和年的乡愁

微信公众号：moviesss 首发于 MOViE木卫 看《龙猫》，至少是十几年前的回忆了。 印象最深的吉卜力作品观影记忆，是高考结束不久，去山里找朋友。 当时没什么娱乐手段，连单机版的星际可能都没有。我就对着电脑硬盘上，不多的影视资源，一个个看掉。 放心，并没有爱情动作片。其... (展开)
120 6 15回应 收起
良欢 2008-11-16 12:48:28

## 爱是最美的拥有

小淑女曾经说：“ 《龙猫》是我过去最好的朋友常看的一部片子，现在她早已从我生活中隐去，不在了，消失了。当年，大夏天被她拉去看这片子的情景仍毫发毕现，我没看完，她却早已熟知细节。数年后的今天，我仍不明白，我们曾经的爱是被时间默认了，还是否定了。” 这段话，写在... (展开)
142 10 42回应 收起
我爱看电影 2017-03-25 10:52:08

## 原来梦是可以看见的

这部电影给带来一种温暖和幸福的感觉，这种温暖和幸福缓如流水，不像其他多部影片那样以触目惊心的自然破坏的结果震撼人心，而直接给观者最理想的家园，让人憧憬、使人向往。 这部动画的主角是姐妹俩个。一个懂事、一个顽皮，但都同样善良天真，具有属于孩子最宝贵的东西。姐... (展开)
74 5 2回应 收起
昨夜星辰恰似你 2017-07-30 23:38:54

## 龙猫

1、生活坏到一定程度就会好起来，因为它无法更坏。努力过后，才知道许多事情，坚持坚持，就过来了。 2、什么时候我们开始无法像孩子一样肆意地大呼小叫了？心里的小情绪堆积得像山一样高，直到溢出来。 与其如此，不如永远像孩子一样。 3、有时我沉默，不是不快乐，只是想把... (展开)
79 1 3回应 收起

> 更多影评 2626篇

添加新讨论

## 讨论区 · · · · · ·

治愈系龙猫 | 来自绯樱花舞 |  | 2022-11-18 09:35:59
要是花400多元买一盒日版《龙猫》BD值得买吗？ | 来自🎬 | 46 回应 | 2022-11-16 07:48:47
《龙猫》——珍惜大自然，保护大自然 | 来自小刘刘 |  | 2022-11-10 13:57:36
有没有人看《龙猫》看哭的？ | 来自🎬 | 70 回应 | 2022-11-07 14:44:54
怎么才能拥有一只龙猫(*¯︶¯*) | 来自弓兵策宋老师 |  | 2022-11-06 07:44:28

> 去这部影片的讨论区（全部622条）

## 关于《龙猫》的问题 · · · · · · ( 全部24个 )

- 片中日本的历法问题？ 6人回答
- 难道没有人像我一样反对又反感将南美鼠当做龙猫吗？ 6人回答

> 全部24个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- 【大爱の日剧♂电影♀动画全收录】 (狷介有乌青)
- 治愈系动画推荐 ([己注销])
- 【爱看动画】 (影志)
- 适合夏天的电影 (sora)

## 谁在看这部电影 · · · · · ·

- Victor
  1分钟前 看过
- momo
  5分钟前 看过
- pupuさん
  11分钟前 看过

2361734人看过 / 375399人想看

订阅龙猫的评论:
feed: rss 2.0